==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/is-IS/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Þessi notandi getur skráð sig inn',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Eignum úthlutað til :name',
    'bulk_update_warn'	=> 'You are about to edit the properties of :user_count users. Please note that you cannot change your own user attributes using this form, and must make edits to your own user individually.',
    'bulk_update_help'	=> 'This form allows you to update multiple users at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged.',
    'current_assets'    => 'Eignir sem ráðstafað hefur verið til þessa notanda',
    'clone'             => 'Afrita notenda',
    'contact_user'      => 'Tengiliður :name',
    'edit'              => 'Breyta notanda',
    'filetype_info'     => 'Leyfðar skráar týpur eru png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Saga :name',
    'info'				=> 'Upplýsingar',
    'restore_user'		=> 'Click here to restore them.',
    'last_login'        => 'Siðasta innskráning',
    'ldap_config_text'  => 'LDAP configuration settings can be found Admin > Settings. The (optional) selected location will be set for all imported users.',
    'print_assigned'    => 'Prenta allt skráð',
    'email_assigned'    => 'Senda t-póst með öllum skráðum búnaði (Email List of All Assigned)',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Skoða notanda :name',
    'usercsv'           => 'CSV skrá',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'Þú ert að fara skrá ALLA hluti inn frá :count user(s) hér að neðan. Nöfn kerfisstjórar eru uppljómuð með rauðu.',
    'update_user_assets_status' => 'Uppfæra allar eignir fyrir þessa notendur í þessa stöðu',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/is-IS/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Þessi notandi getur skráð sig inn',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Eignum úthlutað til :name',
    'bulk_update_warn'	=> 'You are about to edit the properties of :user_count users. Please note that you cannot change your own user attributes using this form, and must make edits to your own user individually.',
    'bulk_update_help'	=> 'This form allows you to update multiple users at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged.',
    'current_assets'    => 'Eignir sem ráðstafað hefur verið til þessa notanda',
    'clone'             => 'Afrita notenda',
    'contact_user'      => 'Tengiliður :name',
    'edit'              => 'Breyta notanda',
    'filetype_info'     => 'Leyfðar skráar týpur eru png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Saga :name',
    'info'				=> 'Upplýsingar',
    'restore_user'		=> 'Click here to restore them.',
    'last_login'        => 'Siðasta innskráning',
    'ldap_config_text'  => 'LDAP configuration settings can be found Admin > Settings. The (optional) selected location will be set for all imported users.',
    'print_assigned'    => 'Prenta allt skráð',
    'email_assigned'    => 'Senda t-póst með öllum skráðum búnaði (Email List of All Assigned)',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Software Checked out to :name',
    'view_user'         => 'Skoða notanda :name',
    'usercsv'           => 'CSV skrá',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'Þú ert að fara skrá ALLA hluti inn frá :count user(s) hér að neðan. Nöfn kerfisstjórar eru uppljómuð með rauðu.',
    'update_user_assets_status' => 'Uppfæra allar eignir fyrir þessa notendur í þessa stöðu',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
    'department_manager' => 'Department Manager',
];
